==> auto_animated-2.0.0-dev.3.tar.gz: example/lib/screens/icon_button.dart <==
import 'package:flutter/material.dart';
import 'package:auto_animated/auto_animated.dart';

class AutoAnimatedIconButtonExample extends StatefulWidget {
  @override
  _AutoAnimatedIconButtonExampleState createState() =>
      _AutoAnimatedIconButtonExampleState();
}

class _AutoAnimatedIconButtonExampleState
    extends State<AutoAnimatedIconButtonExample> {
  bool _externalState = false;

  @override
  Widget build(BuildContext context) => Scaffold(
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Padding(
                padding: EdgeInsets.all(16),
                child: AppBar(
                  primary: false,
                  title: Text('Auto animated Icon'),
                  // Implement animated icon
                  leading: AutoAnimatedIconButton(
                    icon: AnimatedIcons.menu_close,
                    firstTooltip: 'Menu',
                    secondTooltip: 'Close',
                    onPressed: () {},
                  ),
                ),
              ),
              AutoAnimatedIconButton.externalState(
                icon: AnimatedIcons.arrow_menu,
                onPressed: () {
                  setState(() {
                    _externalState = !_externalState;
                  });
                },
                iconState: !_externalState ? IconState.first : IconState.second,
              ),
              AutoAnimatedIconButton(
                icon: AnimatedIcons.play_pause,
                onPressed: () {},
              ),
              AutoAnimatedIconButton(
                icon: AnimatedIcons.search_ellipsis,
                onPressed: () {},
              ),
            ],
          ),
        ),
      );
}

==> auto_animated-3.0.0.tar.gz: example/lib/screens/icon_button.dart <==
import 'package:flutter/material.dart';
import 'package:auto_animated/auto_animated.dart';

class LiveIconButtonExample extends StatefulWidget {
  @override
  _LiveIconButtonExampleState createState() => _LiveIconButtonExampleState();
}

class _LiveIconButtonExampleState extends State<LiveIconButtonExample> {
  bool _externalState = false;

  @override
  Widget build(BuildContext context) => Scaffold(
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Padding(
                padding: EdgeInsets.all(16),
                child: AppBar(
                  primary: false,
                  title: Text('Auto animated Icon'),
                  // Implement animated icon
                  leading: LiveIconButton(
                    icon: AnimatedIcons.menu_close,
                    firstTooltip: 'Menu',
                    secondTooltip: 'Close',
                    onPressed: () {},
                  ),
                ),
              ),
              LiveIconButton.externalState(
                icon: AnimatedIcons.arrow_menu,
                onPressed: () {
                  setState(() {
                    _externalState = !_externalState;
                  });
                },
                iconState: !_externalState ? IconState.first : IconState.second,
              ),
              LiveIconButton(
                icon: AnimatedIcons.play_pause,
                onPressed: () {},
              ),
              LiveIconButton(
                icon: AnimatedIcons.search_ellipsis,
                onPressed: () {},
              ),
            ],
          ),
        ),
      );
}
